/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.render;

import com.vividsolutions.jts.geom.Geometry;
import java.awt.*;
import javax.swing.JPanel;
import nl.cloudfarming.client.geoviewer.Geometrical;

/**
 * Default preview panel which shows a preview of a geometrical object
 * 
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class GeometricalPreviewPanel extends JPanel {

    private final Geometrical geometrical;

    public GeometricalPreviewPanel(Geometrical geometrical) {
        this.geometrical = geometrical;
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);

        //
        // draw the geometry
        //
        Graphics2D gd = (Graphics2D) g.create();
        Geometry geometry = geometrical.getGeometry();

        if (geometry != null && geometry.getCoordinates().length > 1) {
            GeometryRenderer renderer = GeometryRendererFactory.getRenderer(geometry);
            renderer.render(geometry, geometry.getEnvelope(), getVisibleRect(), new SimpleGeoTranslator(), gd);
        }
        gd.dispose();
    }
}
