/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer.render;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import javax.swing.JPanel;
import nl.cloudfarming.client.geoviewer.Palette;
import org.geotools.coverage.grid.GridCoverage2D;
import org.netbeans.api.visual.model.ObjectState;

/**
 * Panel which displays a GridCoverage2D object
 *
 * <p>Uses the {@link RasterRenderer} to render the content on the
 * JPanel</p>
 *
 * @author Timon Veenstra
 * @author Maciek Dulkiewicz
 */
public class GridCoverage2DPreviewPanel extends JPanel {

    private GridCoverage2D coverage;

    public GridCoverage2DPreviewPanel(GridCoverage2D gridCoverage) {
        coverage = gridCoverage;
    }

    @Override
    public void paint(Graphics g) {
        RasterRenderer rasterRenderer = RasterRendererFactory.getRenderer(coverage);
        rasterRenderer.paint(coverage, getVisibleRect(), (Graphics2D) g, new Palette(Color.BLACK), ObjectState.createNormal(), new SimpleGeoTranslator());
    }
    
    public void setGridCoverage2D(GridCoverage2D gridCoverage) {
        this.coverage = gridCoverage;
        repaint();
    }
}
