/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.render;

import com.vividsolutions.jts.awt.PolygonShape;
import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Polygon;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.Collection;

/**
 * Render a polygon, including holes.
 * @author johan
 */
public class PolygonRenderer extends GeometryRenderer<Polygon> {

    @Override
    public void render(Polygon geometry, Geometry boundingBox, Rectangle canvas, GeoTranslator translator, Graphics2D g) {

        Coordinate[] shell = translate(geometry.getExteriorRing().getCoordinates(), boundingBox, canvas, translator);
        Collection holes = new ArrayList(geometry.getNumInteriorRing());
        
        for (int i = 0; i < geometry.getNumInteriorRing(); i++) {
            holes.add(translate(geometry.getInteriorRingN(i).getCoordinates(), boundingBox, canvas, translator));
        }
        
        PolygonShape polygonShape = new PolygonShape(shell, holes);
        g.fill(polygonShape);
    }
    
    private Coordinate[] translate(Coordinate[] coordinates, Geometry boundingBox, Rectangle canvas, GeoTranslator translator) {
        Coordinate[] translated = new Coordinate[coordinates.length];
        
        for (int i = 0; i < coordinates.length; i++) {
            Point2D point2D = translator.geoToPixel(canvas, boundingBox, coordinates[i]);
            double x = point2D.getX() - canvas.getBounds().getX();
            double y = point2D.getY() - canvas.getBounds().getY();
            translated[i] = new Coordinate(x, y);
        }
        
        return translated;
    }
    
}
